@@ -138,10 +138,6 @@ class Document;
  *      KXMLGUIClient
  * \author Christoph Cullmann \<cullmann@kde.org\>
  */
-// KDE5: consider deriving from QFrame instead of QWidget, since e.g. the Oxygen style
-// http://lxr.kde.org/source/kde/kde-workspace/kstyles/oxygen/oxygenstyle.cpp#614
-// checks for a QFrame and then KStyle::pixelMetric returns a better margin (Frame_FrameWidth)
-// This is needed because the Oxygen "focus border" paints over the line numbers otherwise.
 class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
 {
   Q_OBJECT
@@ -192,7 +188,6 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * whatever other edit modes are supported. The string should be
      * translated (i18n), as this is a user aimed representation of the view
      * state, which should be shown in the GUI, for example in the status bar.
-     * This string may be rich-text.
      * \return
      * \see viewModeChanged()
      */
@@ -203,9 +198,8 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * These correspond to various modes the text editor might be in.
      */
     enum EditMode {
-      EditInsert = 0,    /**< Insert mode. Characters will be added. */
-      EditOverwrite = 1, /**< Overwrite mode. Characters will be replaced. */
-      EditViMode = 2     /**< Vi mode. The view will behave like the editor vi(m) @since 4.11 */
+      EditInsert = 0,   /**< Insert mode. Characters will be added. */
+      EditOverwrite = 1 /**< Overwrite mode. Characters will be replaced. */
     };
 
     /**
@@ -288,7 +282,7 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      *
      * \warning Use this with care! Plugin xml gui clients are not merged
      *          into this menu!
-     * \warning !!!!!! DON'T USE THIS FUNCTION, UNLESS YOU ARE SURE YOU DON'T WANT PLUGINS TO WORK !!!!!!
+     * \warning !!!!!! DONT USE THIS FUNCTION, UNLESS YOU ARE SURE YOU DON'T WANT PLUGINS TO WORK !!!!!!
      *
      * \param menu new context menu object for this view
      * \see contextMenu()
@@ -391,14 +385,7 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
     virtual QPoint cursorToCoordinate(const KTextEditor::Cursor& cursor) const = 0;
 
     /**
-     * Get the coordinates (x/y) of the cursor position in pixels.
-     * The returned coordinates are relative to the View.
-     * If global screen coordinates are required, e.g. for showing a QToolTip,
-     * conversion as follows is required:
-     * \code
-     * QPoint viewCoordinates = view->cursorPositionCoordinates();
-     * QPoint globalCoorinates = view->mapToGlobal(viewCoordinates);
-     * \endcode
+     * Get the screen coordinates (x/y) of the cursor position in pixels.
      * \return cursor screen coordinates
      */
     virtual QPoint cursorPositionCoordinates () const = 0;
@@ -502,10 +489,11 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * \param length if >0 \p position defines the start of the selection,
      *        if <0 \p position specifies the end
      * \param wrap if \e false the selection does not wrap lines and reaches
-     *        only to start/end of the cursors line. Default: \e true.
-     *        Warning: \e true was never implemented in KDE 4.
+     *        only to start/end of the cursors line. Default: \e true
      * \see selectionRange(), selection()
-     * \todo remove in KDE5 in favour of Range based setSelection()
+     *
+     * \todo rodda - is this really needed? it can now be accomplished with
+     *       SmartCursor::advance()
      */
     virtual bool setSelection ( const Cursor &position,
                                 int length,
@@ -632,9 +620,7 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
  *
  * \see KTextEditor::View
  * \since 4.2
- * \note KDE5: merge into KTextEditor::View (or name it ViewportInterface
- *       and add accessors to the QScrollBars and convenience functions like
- *       cursorToCoordinate(), scollLines(int count), etc.
+ * \note KDE5: merge into KTextEditor::View
  */
 class KTEXTEDITOR_EXPORT CoordinatesToCursorInterface
 {
