@@ -186,7 +186,7 @@ KTextEditor::Cursor KateScriptDocument::rfind(int line, int column, const QStrin
   QScopedPointer<KTextEditor::MovingCursor> cursor(document()->newMovingCursor(KTextEditor::Cursor(line, column)));
   const int start = cursor->line();
   QList<KTextEditor::Attribute::Ptr> attributes =
-      m_document->highlight()->attributes(((KateView*)m_document->activeView())->renderer()->config()->schema());
+      m_document->highlight()->attributes(static_cast<KateView*>(m_document->activeView())->renderer()->config()->schema());
 
   do {
     Kate::TextLine textLine = m_document->plainKateTextLine(cursor->line());
@@ -227,7 +227,7 @@ KTextEditor::Cursor KateScriptDocument::rfind(const KTextEditor::Cursor& cursor,
 KTextEditor::Cursor KateScriptDocument::anchor(int line, int column, QChar character)
 {
   QList<KTextEditor::Attribute::Ptr> attributes =
-      m_document->highlight()->attributes(((KateView*) m_document->activeView())->renderer()->config()->schema());
+      m_document->highlight()->attributes(static_cast<KateView*>( m_document->activeView())->renderer()->config()->schema());
   int count = 1;
   QChar lc;
   QChar rc;
@@ -679,7 +679,7 @@ bool KateScriptDocument::isAttribute(const KTextEditor::Cursor& cursor, int attr
 
 QString KateScriptDocument::attributeName(int line, int column)
 {
-  QList<KTextEditor::Attribute::Ptr> attributes = m_document->highlight()->attributes(((KateView*) m_document->activeView())->renderer()->config()->schema());
+  QList<KTextEditor::Attribute::Ptr> attributes = m_document->highlight()->attributes(static_cast<KateView*>(m_document->activeView())->renderer()->config()->schema());
   KTextEditor::Attribute::Ptr a = attributes[document()->plainKateTextLine(line)->attribute(column)];
   return a->property(KateExtendedAttribute::AttributeName).toString();
 }
