@@ -242,6 +242,9 @@ class KATEPART_TESTS_EXPORT KateDocumentConfig : public KateConfig
     void setRemoveSpaces (bool on);
     bool removeSpaces () const;
 
+    void setNewLineAtEof (bool on);
+    bool newLineAtEof () const;
+
     void setOvr (bool on);
     bool ovr () const;
 
@@ -359,6 +362,8 @@ class KATEPART_TESTS_EXPORT KateDocumentConfig : public KateConfig
     bool m_removeTrailingDyn : 1;
     bool m_removeSpacesSet : 1;
     bool m_removeSpaces : 1;
+    bool m_newLineAtEofSet : 1;
+    bool m_newLineAtEof : 1;
     bool m_overwiteModeSet : 1;
     bool m_overwiteMode : 1;
     bool m_tabIndentsSet : 1;
@@ -650,16 +655,22 @@ class KateRendererConfig : public KateConfig
     const QColor& tabMarkerColor() const;
     void setTabMarkerColor (const QColor &col);
 
+    const QColor& indentationLineColor() const;
+    void setIndentationLineColor (const QColor &col);
+
     const QColor& iconBarColor() const;
     void setIconBarColor (const QColor &col);
 
+    const QColor& foldingColor() const;
+    void setFoldingColor (const QColor &col);
+
     // the line number color is used for the line numbers on the left bar and
     // for vertical separator lines and for code folding lines.
     const QColor& lineNumberColor() const;
     void setLineNumberColor (const QColor &col);
 
     const QColor& spellingMistakeLineColor() const;
-    void setSpellingMistakeKineColor (const QColor &col);
+    void setSpellingMistakeLineColor (const QColor &col);
 
     bool showIndentationLines () const;
     void setShowIndentationLines (bool on);
@@ -672,6 +683,17 @@ class KateRendererConfig : public KateConfig
     const QColor &templateFocusedEditablePlaceholderColor() const;
     const QColor &templateNotEditablePlaceholderColor() const;
 
+    const QColor& modifiedLineColor() const;
+    void setModifiedLineColor(const QColor &col);
+
+    const QColor& savedLineColor() const;
+    void setSavedLineColor(const QColor &col);
+
+    const QColor& searchHighlightColor() const;
+    void setSearchHighlightColor(const QColor &col);
+
+    const QColor& replaceHighlightColor() const;
+    void setReplaceHighlightColor(const QColor &col);
 
   private:
     /**
@@ -691,7 +713,9 @@ class KateRendererConfig : public KateConfig
     QColor m_highlightedBracketColor;
     QColor m_wordWrapMarkerColor;
     QColor m_tabMarkerColor;
+    QColor m_indentationLineColor;
     QColor m_iconBarColor;
+    QColor m_foldingColor;
     QColor m_lineNumberColor;
     QColor m_spellingMistakeLineColor;
     QVector<QColor> m_lineMarkerColor;
@@ -701,6 +725,10 @@ class KateRendererConfig : public KateConfig
     QColor m_templateFocusedEditablePlaceholderColor;
     QColor m_templateNotEditablePlaceholderColor;
 
+    QColor m_modifiedLineColor;
+    QColor m_savedLineColor;
+    QColor m_searchHighlightColor;
+    QColor m_replaceHighlightColor;
 
     bool m_schemaSet : 1;
     bool m_fontSet : 1;
@@ -713,10 +741,16 @@ class KateRendererConfig : public KateConfig
     bool m_highlightedBracketColorSet : 1;
     bool m_wordWrapMarkerColorSet : 1;
     bool m_tabMarkerColorSet : 1;
+    bool m_indentationLineColorSet : 1;
     bool m_iconBarColorSet : 1;
+    bool m_foldingColorSet : 1;
     bool m_lineNumberColorSet : 1;
     bool m_spellingMistakeLineColorSet : 1;
     bool m_templateColorsSet : 1;
+    bool m_modifiedLineColorSet : 1;
+    bool m_savedLineColorSet : 1;
+    bool m_searchHighlightColorSet : 1;
+    bool m_replaceHighlightColorSet : 1;
     QBitArray m_lineMarkerColorSet;
 
   private:
